fuzzel-pass-0.1.0 is not a library.
fuzzel-pass
A password-store frontend for auto-typing passwords
Statuses
Requirements
- fuzzel - a menu graphical menu compatible with dmenu protocol
- wtype - a tool used to send keyboard inputs to the compositor
- pass - an password manager using gpg and git
- any Wayland compositor accepting inputs from wtype
Building
Ensure you have a rust toolchain installed, and simply run:
Install
For now no package is provided to any distro, they might appear in the future.